Description Usage Arguments Value
Initialises log Book parameters, starts a "session" (which is basically just a directory to store stuff). This means making a directory. Parameters are set in the following order: - package defaults. - previously set values in this R session. - values from RLOGBOOK_<> environmental variables. - values passed to this function.
1 | initLogBook(baseDir, ...)
|
baseDir |
The top level directory where sessions are logged. Can be omitted if set by RLOGBOOK_baseDir or an earlier call to |
... |
Extra parameters to be set. |
Nothing, but a new session is created and plots can now be logged.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.