openPlot: Open a new plot

Description Usage Arguments Value

Description

Opens a new plot in the active session folder. The plot will be named using the current time and the RLogBook params.

Usage

1
openPlot(plotName, ...)

Arguments

plotName

Extra name to append to automatic file name.

...

Extra arguments passed to plot creation function.

Value

Nothing.


constantAmateur/RLogBook documentation built on May 11, 2019, 6:26 p.m.