renameSession: Rename an open session

Description Usage Arguments

Description

Renames an existing session. This basically just adds a prefix to the existing session folder and updates all the sym-links. It doesn't change the time stamp for the directory or anything else.

Usage

1
renameSession(sessionName)

Arguments

sessionName

The new session name to use.


constantAmateur/RLogBook documentation built on May 11, 2019, 6:26 p.m.