Description Usage Arguments Value
Opens a new plot in the active session folder. The plot will be named using the current time and the RLogBook params.
1 |
plotName |
Extra name to append to automatic file name. |
... |
Extra arguments passed to plot creation function. |
Nothing.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.