Renames an existing session. This basically just adds a prefix to the existing session folder and updates all the sym-links. It doesn't change the time stamp for the directory or anything else.
1 | renameSession(sessionName)
|
sessionName |
The new session name to use. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.